==> ejc-proother-impl-3.0.0-20220520.083633-73-sources.jar: com/ejianc/business/proother/service/impl/ContractBpmServiceImpl.java <==
package com.ejianc.business.proother.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.proother.bean.ContractEntity;
import com.ejianc.business.proother.enums.BillPushStatusEnum;
import com.ejianc.business.proother.enums.DraftTypeEnum;
import com.ejianc.business.proother.enums.PerformanceStatusEnum;
import com.ejianc.business.proother.enums.SignatureStatusEnum;
import com.ejianc.business.proother.service.IContractService;
import com.ejianc.business.proother.vo.ContractVO;
import com.ejianc.business.signaturemanage.api.ISignatureCommonApi;
import com.ejianc.business.signaturemanage.vo.WatermarkConfigVO;
import com.ejianc.business.signaturemanage.vo.WatermarkVO;
import com.ejianc.foundation.file.vo.AttachmentVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;

@Service("contract")
public class ContractBpmServiceImpl implements ICommonBusinessService {

	private Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private IContractService contractService;

	@Autowired
	private IBillTypeApi billTypeApi;

	@Autowired
	private SessionManager sessionManager;

	@Autowired
	private ISignatureCommonApi signatureCommonApi;


	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		ContractEntity e = contractService.selectById(billId);
		logger.info("审批节点审批中时节点审批前回调:  当前数据-{}", JSONObject.toJSONString(e));
		//线上起草且文件未同步
		if((DraftTypeEnum.线上起草.getCode().equals(e.getDraftType()) || DraftTypeEnum.线上起草不使用电子签章.getCode().equals(e.getDraftType())) && !e.getContractFileSyncFlag()) {
			return CommonResponse.error("请重新进行合同编辑，同步单据信息到合同文件！");
		}

		return CommonResponse.success("审批处理成功！");
	}

	/**
	 * 有审批流提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		ContractEntity e = contractService.selectById(billId);

		if(DraftTypeEnum.线上起草.getCode().equals(e.getDraftType()) || DraftTypeEnum.线上起草不使用电子签章.getCode().equals(e.getDraftType())) {
			if(null == e.getContractFileId()) {
				//确保线上起草方式时，用户已编辑合同文件
				return CommonResponse.error("请编辑合同文件并保存后再执行此操作！");
			}
			if(!e.getContractFileSyncFlag()) {
				return CommonResponse.error("请重新进行合同编辑，同步单据信息到合同文件！");
			}
		}

		UserContext userContext = sessionManager.getUserContext();
		e.setCommitDate(new Date());
		e.setCommitUserCode(userContext.getUserCode());
		e.setCommitUserName(userContext.getUserName());
		contractService.saveOrUpdate(e,false);

		return CommonResponse.success("合同审批回调处理成功！");
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		/*
			起草方式为线下签订则不需要签章
			当不使用电子签章时：创建时默认为待签章，单据审批通过后自动更改为【已签章】
			当签章状态变为【已签章】时，合同状态变为【履约中】
		 */
		ContractEntity contractEntity = contractService.selectById(billId);
		if (contractEntity != null){

			if((DraftTypeEnum.线下签订.getCode().toString()).equals(contractEntity.getDraftType())) {
				//线下签订合同无需进行签章操作，则审批通过后直接置为已生效状态
				logger.info("合同id-{}为线下签订直接修改为签章状态并设置为履约中", billId);
				contractEntity.setSignatureStatus(SignatureStatusEnum.已签章.getCode());
				contractEntity.setPerformanceStatus(PerformanceStatusEnum.履约中.getCode());
				//合同已生效，添加生效时间
				contractEntity.setEffectiveDate(new Date());
			} else if(DraftTypeEnum.线上起草.getCode().equals(contractEntity.getDraftType()) || DraftTypeEnum.线上起草不使用电子签章.getCode().equals(contractEntity.getDraftType())) {
				if(null == contractEntity.getContractFileId()) {
					//确保线上起草方式时，用户已编辑合同文件
					return CommonResponse.error("请编辑合同文件并保存后再执行此操作！");
				}
				if(!contractEntity.getContractFileSyncFlag()) {
					return CommonResponse.error("请重新进行合同编辑，同步单据信息到合同文件！");
				}
			}
		}

		if(state.equals(BillStateEnum.COMMITED_STATE.getBillStateCode())) {
			//直审时添加单据提交人等信息
			contractEntity.setCommitDate(new Date());
			contractEntity.setCommitUserCode(sessionManager.getUserContext().getUserCode());
			contractEntity.setCommitUserName(sessionManager.getUserContext().getUserName());
		}

		//合同推送合同池
		boolean pushResult = contractService.pushContract(BeanMapper.map(contractEntity, ContractVO.class));
		if(pushResult) {
			contractEntity.setBillPushFlag(BillPushStatusEnum.推送成功.getStatus());
		} else {
			contractEntity.setBillPushFlag(BillPushStatusEnum.未成功推送.getStatus());
		}

		// 合同添加水印
		WatermarkVO watermarkVO = new WatermarkVO();
		watermarkVO.setScheme("QI_YUE_SUO");
		watermarkVO.setFileId(contractEntity.getContractFileId());
		watermarkVO.setBillId(contractEntity.getId());
		watermarkVO.setBillType("BT220308000000001");
		watermarkVO.setSourceType("prootherContract");

		ArrayList<WatermarkConfigVO> watermarks = new ArrayList<>();
		WatermarkConfigVO vo = new WatermarkConfigVO();
		vo.setType("TEXT");
		vo.setContent("北京益企联科技有限公司");
		vo.setImageBase64("");
		vo.setFontSize(48);
		vo.setColor("#999999");
		vo.setRotateAngle(30.0D);
		vo.setTransparency(0.5D);
		vo.setLocation("MIDDLE_CENTER");
		watermarks.add(vo);
		watermarkVO.setWatermarkConfigs(watermarks);

		AttachmentVO attachmentVO = signatureCommonApi.fetchWatermarkAttachment(watermarkVO);
		if (attachmentVO == null) {
			logger.error("调用签章中心获取合同水印附件失败！");
			throw new BusinessException("调用签章中心获取合同水印附件失败！");
		}
		contractEntity.setWatermarkContractFileId(attachmentVO.getId());

		contractService.saveOrUpdate(contractEntity);
		return CommonResponse.success("合同审批回调成功！");
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return bpmBackCheck(billId, state, billTypeCode);
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		return bpmBackCheck(billId, state, billTypeCode);
	}

	private CommonResponse<String> bpmBackCheck(Long billId, Integer state, String billTypeCode) {
		/*
			弃审逻辑：
			1、审批过程中，支持后台弃审；
			2、当审批通过，且没有走签章流程且没有下游业务时，支持后台弃审；
		 */
		ContractEntity contractEntity = contractService.selectById(billId);

		// 审批可以撤回的签章状态集合
		ArrayList<String> statusList = new ArrayList<>();
		statusList.add(SignatureStatusEnum.待签章.getCode());
		statusList.add(SignatureStatusEnum.已退回.getCode());
		statusList.add(SignatureStatusEnum.已撤回.getCode());
		statusList.add(SignatureStatusEnum.已过期.getCode());

		if(DraftTypeEnum.线上起草.getCode().equals(contractEntity.getDraftType()) || DraftTypeEnum.上传合同.getCode().equals(contractEntity.getDraftType())) {
			if (!statusList.contains(contractEntity.getSignatureStatus())){
				return CommonResponse.error("当前单据已有签章流程，不能撤回！");
			}
		} else if(SignatureStatusEnum.已签章.getCode().equals(contractEntity.getSignatureStatus())) {
			contractEntity.setSignatureStatus(SignatureStatusEnum.待签章.getCode());
		}

		if(PerformanceStatusEnum.履约中.getCode().equals(contractEntity.getPerformanceStatus())) {
			contractEntity.setPerformanceStatus(PerformanceStatusEnum.未签订.getCode());
		}

		//合同是否被其他单据引用
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode,billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());

		if(!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}

		//从合同池删除数据
		boolean delResult = contractService.delContractFromPool(contractEntity.getId());
		if(delResult) {
			contractEntity.setBillPushFlag(BillPushStatusEnum.未成功推送.getStatus());
		}

		// 删除文件中心水印文件
		if(contractEntity.getWatermarkContractFileId() != null) {
			boolean delWatermarkflag = contractService.delWatermarkContractFile(contractEntity.getWatermarkContractFileId());
			if (delWatermarkflag) {
				contractEntity.setWatermarkContractFileId(null);
			}
		}

		contractService.saveOrUpdate(contractEntity, false);

		return CommonResponse.success("弃审/撤回前校验回调成功！");
	}


}

==> ejc-proother-impl-3.0.0-20220524.064747-89-sources.jar: com/ejianc/business/proother/service/impl/ContractBpmServiceImpl.java <==
package com.ejianc.business.proother.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.proother.bean.ContractEntity;
import com.ejianc.business.proother.enums.BillPushStatusEnum;
import com.ejianc.business.proother.enums.DraftTypeEnum;
import com.ejianc.business.proother.enums.PerformanceStatusEnum;
import com.ejianc.business.proother.enums.SignatureStatusEnum;
import com.ejianc.business.proother.service.IContractAsyncService;
import com.ejianc.business.proother.service.IContractService;
import com.ejianc.business.proother.vo.ContractVO;
import com.ejianc.business.signaturemanage.api.ISignatureCommonApi;
import com.ejianc.business.signaturemanage.vo.WatermarkConfigVO;
import com.ejianc.business.signaturemanage.vo.WatermarkVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;

@Service("contract")
public class ContractBpmServiceImpl implements ICommonBusinessService {

	private Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private IContractService contractService;

	@Autowired
	private IBillTypeApi billTypeApi;

	@Autowired
	private SessionManager sessionManager;

	@Autowired
	private ISignatureCommonApi signatureCommonApi;
	@Autowired
	private IContractAsyncService contractAsyncService;


	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		ContractEntity e = contractService.selectById(billId);
		logger.info("审批节点审批中时节点审批前回调:  当前数据-{}", JSONObject.toJSONString(e));
		//线上起草且文件未同步
		if((DraftTypeEnum.线上起草.getCode().equals(e.getDraftType()) || DraftTypeEnum.线上起草不使用电子签章.getCode().equals(e.getDraftType())) && !e.getContractFileSyncFlag()) {
			return CommonResponse.error("请重新进行合同编辑，同步单据信息到合同文件！");
		}

		return CommonResponse.success("审批处理成功！");
	}

	/**
	 * 有审批流提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		ContractEntity e = contractService.selectById(billId);

		if(DraftTypeEnum.线上起草.getCode().equals(e.getDraftType()) || DraftTypeEnum.线上起草不使用电子签章.getCode().equals(e.getDraftType())) {
			if(null == e.getContractFileId()) {
				//确保线上起草方式时，用户已编辑合同文件
				return CommonResponse.error("请编辑合同文件并保存后再执行此操作！");
			}
			if(!e.getContractFileSyncFlag()) {
				return CommonResponse.error("请重新进行合同编辑，同步单据信息到合同文件！");
			}
		}

		UserContext userContext = sessionManager.getUserContext();
		e.setCommitDate(new Date());
		e.setCommitUserCode(userContext.getUserCode());
		e.setCommitUserName(userContext.getUserName());
		contractService.saveOrUpdate(e,false);

		return CommonResponse.success("合同审批回调处理成功！");
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		/*
			起草方式为线下签订则不需要签章
			当不使用电子签章时：创建时默认为待签章，单据审批通过后自动更改为【已签章】
			当签章状态变为【已签章】时，合同状态变为【履约中】
		 */
		ContractEntity contractEntity = contractService.selectById(billId);
		if (contractEntity != null){

			if((DraftTypeEnum.线下签订.getCode().toString()).equals(contractEntity.getDraftType())) {
				//线下签订合同无需进行签章操作，则审批通过后直接置为已生效状态
				logger.info("合同id-{}为线下签订直接修改为签章状态并设置为履约中", billId);
				contractEntity.setSignatureStatus(SignatureStatusEnum.已签章.getCode());
				contractEntity.setPerformanceStatus(PerformanceStatusEnum.履约中.getCode());
				//合同已生效，添加生效时间
				contractEntity.setEffectiveDate(new Date());
			} else if(DraftTypeEnum.线上起草.getCode().equals(contractEntity.getDraftType()) || DraftTypeEnum.线上起草不使用电子签章.getCode().equals(contractEntity.getDraftType())) {
				if(null == contractEntity.getContractFileId()) {
					//确保线上起草方式时，用户已编辑合同文件
					return CommonResponse.error("请编辑合同文件并保存后再执行此操作！");
				}
				if(!contractEntity.getContractFileSyncFlag()) {
					return CommonResponse.error("请重新进行合同编辑，同步单据信息到合同文件！");
				}
			}
		}

		if(state.equals(BillStateEnum.COMMITED_STATE.getBillStateCode())) {
			//直审时添加单据提交人等信息
			contractEntity.setCommitDate(new Date());
			contractEntity.setCommitUserCode(sessionManager.getUserContext().getUserCode());
			contractEntity.setCommitUserName(sessionManager.getUserContext().getUserName());
		}

		//合同推送合同池
		boolean pushResult = contractService.pushContract(BeanMapper.map(contractEntity, ContractVO.class));
		if(pushResult) {
			contractEntity.setBillPushFlag(BillPushStatusEnum.推送成功.getStatus());
		} else {
			contractEntity.setBillPushFlag(BillPushStatusEnum.未成功推送.getStatus());
		}

		// 合同添加水印
		WatermarkVO watermarkVO = new WatermarkVO();
		watermarkVO.setScheme("QI_YUE_SUO");
		watermarkVO.setFileId(contractEntity.getContractFileId());
		watermarkVO.setBillId(contractEntity.getId());
		watermarkVO.setBillType("BT220308000000001");
		watermarkVO.setSourceType("prootherContract");

		ArrayList<WatermarkConfigVO> watermarks = new ArrayList<>();
		WatermarkConfigVO vo = new WatermarkConfigVO();
		vo.setType("TEXT");
		vo.setContent("北京益企联科技有限公司");
		vo.setImageBase64("");
		vo.setFontSize(48);
		vo.setColor("#999999");
		vo.setRotateAngle(30.0D);
		vo.setTransparency(0.5D);
		vo.setLocation("MIDDLE_CENTER");
		watermarks.add(vo);
		watermarkVO.setWatermarkConfigs(watermarks);

		// 获取上下文并异步调用添加水印
		HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes()).getRequest();
		HashMap<String, String> headers = new HashMap<>();
		headers.put("authority", request.getHeader("authority"));
		headers.put("ejc-token", request.getHeader("ejc-token"));
		contractAsyncService.fetchWatermarkAttachment(headers, watermarkVO);

		contractService.saveOrUpdate(contractEntity);
		return CommonResponse.success("合同审批回调成功！");
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return bpmBackCheck(billId, state, billTypeCode);
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		return bpmBackCheck(billId, state, billTypeCode);
	}

	private CommonResponse<String> bpmBackCheck(Long billId, Integer state, String billTypeCode) {
		/*
			弃审逻辑：
			1、审批过程中，支持后台弃审；
			2、当审批通过，且没有走签章流程且没有下游业务时，支持后台弃审；
		 */
		ContractEntity contractEntity = contractService.selectById(billId);

		// 审批可以撤回的签章状态集合
		ArrayList<String> statusList = new ArrayList<>();
		statusList.add(SignatureStatusEnum.待签章.getCode());
		statusList.add(SignatureStatusEnum.已退回.getCode());
		statusList.add(SignatureStatusEnum.已撤回.getCode());
		statusList.add(SignatureStatusEnum.已过期.getCode());

		if(DraftTypeEnum.线上起草.getCode().equals(contractEntity.getDraftType()) || DraftTypeEnum.上传合同.getCode().equals(contractEntity.getDraftType())) {
			if (!statusList.contains(contractEntity.getSignatureStatus())){
				return CommonResponse.error("当前单据已有签章流程，不能撤回！");
			}
		} else if(SignatureStatusEnum.已签章.getCode().equals(contractEntity.getSignatureStatus())) {
			contractEntity.setSignatureStatus(SignatureStatusEnum.待签章.getCode());
		}

		if(PerformanceStatusEnum.履约中.getCode().equals(contractEntity.getPerformanceStatus())) {
			contractEntity.setPerformanceStatus(PerformanceStatusEnum.未签订.getCode());
		}

		//合同是否被其他单据引用
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode,billId);
		logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());

		if(!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}

		//从合同池删除数据
		boolean delResult = contractService.delContractFromPool(contractEntity.getId());
		if(delResult) {
			contractEntity.setBillPushFlag(BillPushStatusEnum.未成功推送.getStatus());
		}

		// 删除文件中心水印文件
		if(contractEntity.getWatermarkContractFileId() != null) {
			boolean delWatermarkflag = contractService.delWatermarkContractFile(contractEntity.getWatermarkContractFileId());
			if (delWatermarkflag) {
				contractEntity.setWatermarkContractFileId(null);
			}
		}

		contractService.saveOrUpdate(contractEntity, false);

		return CommonResponse.success("弃审/撤回前校验回调成功！");
	}


}
